@@ -9,9 +9,9 @@ Class and functions to interact with the volumes: defined in compose files.
 import re
 from copy import deepcopy
 
-from troposphere import AWS_NO_VALUE
-from troposphere import Ref
-from ecs_composex.common import keyisset, LOG
+from troposphere import AWS_NO_VALUE, Ref
+
+from ecs_composex.common import LOG, keyisset
 from ecs_composex.efs.efs_params import FS_REGEXP, RES_KEY
 
 
