@@ -8,27 +8,30 @@ Module for the ComposeXSettings class
 
 from copy import deepcopy
 from datetime import datetime as dt
+from json import loads
+from os import path
 from re import sub
 
 import boto3
+import jsonschema
 import yaml
 from botocore.exceptions import ClientError
 from cfn_flip.yaml_dumper import LongCleanDumper
 from compose_x_render.compose_x_render import ComposeDefinition
+from importlib_resources import files as pkg_files
 
 from ecs_composex import __version__
-from ecs_composex.common import keyisset, LOG, NONALPHANUM
-from ecs_composex.common.aws import get_account_id, get_region_azs
-from ecs_composex.common.aws import get_cross_role_session
+from ecs_composex.common import LOG, NONALPHANUM, keyisset
+from ecs_composex.common.aws import (
+    get_account_id,
+    get_cross_role_session,
+    get_region_azs,
+)
 from ecs_composex.common.cfn_params import USE_FLEET_T
 from ecs_composex.common.compose_networks import ComposeNetwork
-from ecs_composex.common.compose_services import (
-    ComposeService,
-    ComposeFamily,
-)
+from ecs_composex.common.compose_services import ComposeFamily, ComposeService
 from ecs_composex.common.compose_volumes import ComposeVolume
-from ecs_composex.iam import ROLE_ARN_ARG
-from ecs_composex.iam import validate_iam_role_arn
+from ecs_composex.iam import ROLE_ARN_ARG, validate_iam_role_arn
 from ecs_composex.secrets.compose_secrets import ComposeSecret
 from ecs_composex.utils.init_ecs import set_ecs_settings
 from ecs_composex.utils.init_s3 import create_bucket
@@ -53,6 +56,7 @@ class ComposeXSettings(object):
     deploy_arg = "up"
     render_arg = "render"
     create_arg = "create"
+    plan_arg = "plan"
     config_render_arg = "config"
     command_arg = "command"
 
@@ -83,6 +87,10 @@ class ComposeXSettings(object):
             "name": create_arg,
             "help": "Generates & Validates the CFN templates locally. Uploads files to S3",
         },
+        {
+            "name": plan_arg,
+            "help": "Creates a recursive change-set to show the diff prior to an update",
+        },
     ]
     validation_commands = [
         {
@@ -141,6 +149,7 @@ class ComposeXSettings(object):
         self.single_nat = None
         self.lookup_vpc = False
         self.deploy = True if keyisset(self.deploy_arg, kwargs) else False
+        self.plan = True if keyisset(self.plan_arg, kwargs) else False
         self.no_upload = True if keyisset(self.render_arg, kwargs) else False
 
         self.upload = False if self.no_upload else True
@@ -285,7 +294,7 @@ class ComposeXSettings(object):
             self.services.append(service)
 
     def add_new_family(self, family_name, service, assigned_services):
-        if service.name in [service.name for service in assigned_services]:
+        if service.name in [r_service.name for r_service in assigned_services]:
             LOG.info(
                 f"Detected {service.name} is-reused in different family. Making a deepcopy"
             )
@@ -303,7 +312,7 @@ class ComposeXSettings(object):
 
     def handle_assigned_existing_service(self, family_name, service, assigned_services):
         the_family = self.families[family_name]
-        if service.name in [service.name for service in assigned_services]:
+        if service.name in [r_service.name for r_service in assigned_services]:
             LOG.info(
                 f"Detected {service.name} is-reused in different family. Making a deepcopy"
             )
@@ -355,6 +364,16 @@ class ComposeXSettings(object):
         )
         content_def = ComposeDefinition(files, content)
         self.compose_content = content_def.definition
+        source = pkg_files("ecs_composex_specs").joinpath("compose-spec.json")
+        print(source)
+        resolver = jsonschema.RefResolver(
+            f"file://{path.abspath(path.dirname(source))}/", None
+        )
+        jsonschema.validate(
+            content_def.definition,
+            loads(source.read_text()),
+            resolver=resolver,
+        )
         if fully_load:
             self.set_secrets()
             self.set_volumes()
@@ -377,6 +396,9 @@ class ComposeXSettings(object):
         if command == self.deploy_arg:
             self.deploy = True
             self.upload = True
+        elif command == self.plan_arg:
+            self.plan = True
+            self.upload = True
         elif command == self.render_arg:
             self.no_upload = True
             self.upload = not self.no_upload
