@@ -11,9 +11,10 @@ which it heavily relies onto.
 You can change the names *values* so you like so long as you keep it [a-zA-Z0-9]
 """
 
-from troposphere import Select, Split, Ref, ImportValue, Sub
-from ecs_composex.common.ecs_composex import CFN_EXPORT_DELIMITER as delim
+from troposphere import ImportValue, Ref, Select, Split, Sub
+
 from ecs_composex.common.cfn_params import ROOT_STACK_NAME_T, Parameter
+from ecs_composex.common.ecs_composex import CFN_EXPORT_DELIMITER as delim
 from ecs_composex.vpc.vpc_params import SG_ID_TYPE
 
 CLUSTER_T = "EcsCluster"
