@@ -6,13 +6,13 @@
 Module to handle resource settings definition to containers.
 """
 
-from troposphere import Sub, FindInMap, Ref
+from troposphere import FindInMap, Ref, Sub
 from troposphere.iam import Policy as IamPolicy
 
-from ecs_composex.common import LOG, keyisset, add_parameters
+from ecs_composex.common import LOG, add_parameters, keyisset
 from ecs_composex.common.cfn_params import ROOT_STACK_NAME_T
-from ecs_composex.common.services_helpers import extend_container_envvars
 from ecs_composex.common.compose_resources import get_parameter_settings
+from ecs_composex.common.services_helpers import extend_container_envvars
 from ecs_composex.common.stacks import ComposeXStack
 from ecs_composex.ecs.ecs_iam import define_service_containers
 from ecs_composex.ecs.ecs_params import TASK_ROLE_T
@@ -57,6 +57,8 @@ def add_iam_policy_to_service_task_role(
     :return:
     """
     containers = define_service_containers(service_template)
+    print(containers)
+    print(resource.env_vars)
     policy = perms[access_type]
     task_role = service_template.resources[TASK_ROLE_T]
     task_role.Policies.append(policy)
